/*
 * Copyright (c) Members of the EGEE Collaboration. 2004.
 * See http://eu-egee.org/partners/ for details on the copyright holders.
 * For license conditions see the license file or http://eu-egee.org/license.html
 *
 * glite-config.h
 *
 * Authors: Paolo Badino <paolo.badino@cern.ch>
 * Version info: $Id: glite-config.h,v 1.8 2008/01/24 08:43:43 ptedesco Exp $
 * Release: $Name: glite-data-config-service_R_2_0_0_3 $
 *
 */
#ifndef GLITE_DATA_CONFIG_GLITE_CONF_H_
#define GLITE_DATA_CONFIG_GLITE_CONF_H_

#ifdef __cplusplus
extern "C" {
#endif //__cplusplus

/**
 * Initialize the Service using Glite Configuration
 * @param name [IN] the service name
 * @return 0 if success, 1 if already initialized, -1 if failed
 */
int glite_config_initialize(const char * name);
    
/**
 * Reconfigure the Service using Glite Configuration
 * @param name [IN] the service name
 * @return 0 if success, 1 if already initialized, -1 if failed
 */
int glite_config_reconfigure(const char * name);
    
/**
 * Finalize the Service using Glite Configuration
 * @return 0 if success, 1 if already finalized, -1 if failed
 */
int glite_config_finalize();

/**
 * Initialize variables for changing the process name. This method shoudl be
 * called in the main function passing the argc and argv arguments. It may be 
 * used to set the process name of forked child processes
 * @param argc [IN] the number of command line arguments
 * @param argv [IN] the command line arguments
 * @return the maximum length of the name that could be assigned
 */  
int glite_proc_name_init(int argc, char ** argv);

/**
 * Change the process name
 * @param name [IN] the name to assign to the process
 * @return the length of the name assigned to the process
 */
int glite_set_proc_name(const char * name);

#ifdef __cplusplus
}
#endif //__cplusplus

#endif //GLITE_DATA_CONFIG_GLITE_CONF_H_
